
User`s Guide
============

Getting Started
---------------

Before you begin, ensure you have installed Python 3.11 or later.
*syndantic* is compatible with Python 3.11+.

The recommended way of installing this package is via ``pip``.

.. installation::
   :pypi:
   :pypi-name: syndantic
   :github:


.. note::
   You may want to install the package in the user or system  package path
   or in a virtual environment. This is beyond the scope of this
   document. Please, see some dedicated tutorials such as the
   `PYPA Tutorial`_ on
   installing packages with pip and virtual environments.

.. _PYPA Tutorial: https://packaging.python.org/en/latest/guides/installing-using-pip-and-virtual-environments/



Core Concepts
-------------


Troubleshooting
---------------

If anything else goes wrong, please, see if there has already been
opened a corresponding issue. If not, do not hesitate to open a new
issue.
